Index: /code/branches/buildsystem/cmake/CheckTardis.cmake
===================================================================
--- /code/branches/buildsystem/cmake/CheckTardis.cmake	(revision 2053)
+++ /code/branches/buildsystem/cmake/CheckTardis.cmake	(revision 2054)
@@ -42,4 +42,5 @@
   SET(ENV{ALUTDIR} "/usr/pack/openal-0.0.8-cl;/usr/pack/openal-0.0.8-cl/i686-debian-linux3.1")
   SET(ENV{OPENALDIR} "/usr/pack/openal-0.0.8-cl;/usr/pack/openal-0.0.8-cl/i686-debian-linux3.1")
+  SET(ENV{ENETDIR} "/usr/pack/enet-2007-sd;/usr/pack/enet-2007-sd/i686-debian-linux3.1")
   #SET(TCL_INCLUDE_PATH "/usr/pack/tcltk-8.4.9.linux-mo/include")
 ENDIF (IS_TARDIS)
Index: /code/branches/buildsystem/cmake/FindALUT.cmake
===================================================================
--- /code/branches/buildsystem/cmake/FindALUT.cmake	(revision 2053)
+++ /code/branches/buildsystem/cmake/FindALUT.cmake	(revision 2054)
@@ -20,8 +20,4 @@
 # Some simplifications by Adrian Friedli
 #                 > www.orxonox.net <
-
-IF (ALUT_LIBRARY AND ALUT_INCLUDE_DIR)
-  SET (ALUT_FIND_QUIETLY TRUE)
-ENDIF (ALUT_LIBRARY AND ALUT_INCLUDE_DIR)
 
 FIND_PATH(ALUT_INCLUDE_DIR AL/alut.h
@@ -77,21 +73,8 @@
 ENDIF(${ALUT_INCLUDE_DIR} MATCHES ".framework")
 
-SET (ALUT_FOUND "NO")
-IF (ALUT_LIBRARY AND ALUT_INCLUDE_DIR)
-  SET (ALUT_FOUND "YES")
-  IF (NOT ALUT_FIND_QUIETLY)
-    MESSAGE (STATUS "FreeAlut was found.")
-    IF (VERBOSE_FIND)
-      MESSAGE (STATUS "  include path: ${ALUT_INCLUDE_DIR}")
-      MESSAGE (STATUS "  library path: ${ALUT_LIBRARY}")
-      MESSAGE (STATUS "  libraries:    alut")
-    ENDIF (VERBOSE_FIND)
-  ENDIF (NOT ALUT_FIND_QUIETLY)
-ELSE (ALUT_LIBRARY AND ALUT_INCLUDE_DIR)
-  IF (NOT ALUT_INCLUDE_DIR)
-    MESSAGE (SEND_ERROR "FreeAlut include path was not found.")
-  ENDIF (NOT ALUT_INCLUDE_DIR)
-  IF (NOT ALUT_LIBRARY)
-    MESSAGE (SEND_ERROR "FreeAlut library was not found.")
-  ENDIF (NOT ALUT_LIBRARY)
-ENDIF (ALUT_LIBRARY AND ALUT_INCLUDE_DIR)
+# handle the QUIETLY and REQUIRED arguments and set ALUT_FOUND to TRUE if
+# all listed variables are TRUE
+INCLUDE(FindPackageHandleStandardArgs)
+FIND_PACKAGE_HANDLE_STANDARD_ARGS(ALUT DEFAULT_MSG ALUT_LIBRARY ALUT_INCLUDE_DIR)
+
+MARK_AS_ADVANCED(ALUT_LIBRARY ALUT_INCLUDE_DIR)
Index: /code/branches/buildsystem/src/CMakeLists.txt
===================================================================
--- /code/branches/buildsystem/src/CMakeLists.txt	(revision 2053)
+++ /code/branches/buildsystem/src/CMakeLists.txt	(revision 2054)
@@ -17,13 +17,8 @@
 
 # Set the search paths for the linking
+# TODO: remove this after the CMake Modules have been fixed and use absolut paths
 LINK_DIRECTORIES(
   ${OGRE_LIB_DIR}
   ${CEGUI_LIB_DIR}
-#  ${CEGUI_SCRIPT_LIB_DIR}
-#  ${CEGUI_OGRE_LIB_DIR}
-  ${ENet_LIBRARY}
-  ${Boost_LIBRARY_DIRS}
-  ${Zlib_LIBRARY_DIR}
-  ${TCL_LIBRARY}
 )
 
Index: /code/branches/buildsystem/src/network/CMakeLists.txt
===================================================================
--- /code/branches/buildsystem/src/network/CMakeLists.txt	(revision 2053)
+++ /code/branches/buildsystem/src/network/CMakeLists.txt	(revision 2054)
@@ -27,5 +27,5 @@
 TARGET_LINK_LIBRARIES( network
   ${ZLIB_LIBRARY}
-  ${ENet_LIBRARY}
+  ${ENet_LIBRARIES}
   ${Boost_THREAD_LIBRARY}
   core
@@ -43,7 +43,6 @@
     ${OGRE_LIBRARIES}
     network
-    ${ENet_LIBRARY}
+    ${ENet_LIBRARIES}
     ${ZLIB_LIBRARY}
-    ${WINDOWS_ENET_DEPENDENCIES}
   )
   ##### end test for gamestate stuff #####

Index: /code/branches/buildsystem/cmake/FindENet.cmake
===================================================================
--- /code/branches/buildsystem/cmake/FindENet.cmake	(revision 2053)
+++ /code/branches/buildsystem/cmake/FindENet.cmake	(revision 2054)
@@ -3,7 +3,8 @@
 #
 #  ENET_FOUND - system has enet
 #  ENET_INCLUDE_DIR - the enet include directory
 #  ENET_LIBRARIES - the libraries needed to use enet
 #  ENET_DEFINITIONS - Compiler switches required for using enet
 #
 #  Borrowed from The Mana World
@@ -11,55 +12,37 @@
 #
 # Several changes and additions by Fabian 'x3n' Landau
+# Lots of simplifications by Adrian Friedli
 #                 > www.orxonox.net <
 
-IF (ENet_INCLUDE_DIR AND ENet_LIBRARY)
-   SET(ENet_FIND_QUIETLY TRUE)
-ENDIF (ENet_INCLUDE_DIR AND ENet_LIBRARY)
-
 FIND_PATH(ENet_INCLUDE_DIR enet/enet.h
-    /usr/include
-    /usr/local/include
-    /usr/pack/enet-2007-sd/include # Tardis specific hack
-    ../libs/enet-1.1/include
-    ${DEPENDENCY_DIR}/enet-1.2/include
+    PATHS
+    $ENV{ENETDIR}
+    /usr/local
+    /usr
+    PATH_SUFFIXES include
     )
 
 FIND_LIBRARY(ENet_LIBRARY
     NAMES enet
-    PATHS /usr/lib /usr/local/lib /usr/pack/enet-2007-sd/i686-debian-linux3.1/lib/
-    ../libs/enet-1.1
-    ${DEPENDENCY_DIR}/enet-1.2/lib
+    PATHS
+    $ENV{ENETDIR}
+    /usr/local
+    /usr
+    PATH_SUFFIXES lib
     )
 
-SET(ENET_FOUND FALSE)
-IF (ENet_INCLUDE_DIR AND ENet_LIBRARY)
-    SET(ENET_FOUND TRUE)
-    SET(ENET_INCLUDE_DIR ${ENet_INCLUDE_DIR})
+# handle the QUIETLY and REQUIRED arguments and set ENET_FOUND to TRUE if
+# all listed variables are TRUE
+INCLUDE(FindPackageHandleStandardArgs)
+FIND_PACKAGE_HANDLE_STANDARD_ARGS(ENet DEFAULT_MSG ENet_LIBRARY ENet_INCLUDE_DIR)
 
+IF (ENET_FOUND)
     IF(WIN32)
         SET(WINDOWS_ENET_DEPENDENCIES "ws2_32;winmm")
-        SET(ENet_LIBRARY ${ENet_LIBRARY} ${WINDOWS_ENET_DEPENDENCIES})
+        SET(ENet_LIBRARIES ${ENet_LIBRARY} ${WINDOWS_ENET_DEPENDENCIES})
+    ELSE(WIN32)
+        SET(ENet_LIBRARIES ${ENet_LIBRARY})
     ENDIF(WIN32)
-
-    SET(ENET_LIBRARIES ${ENet_LIBRARY})
-ENDIF (ENet_INCLUDE_DIR AND ENet_LIBRARY)
-
-IF (ENET_FOUND)
-    IF (NOT ENet_FIND_QUIETLY)
-        MESSAGE(STATUS "ENet was found.")
-        IF (VERBOSE_FIND)
-            MESSAGE (STATUS "  include path: ${ENet_INCLUDE_DIR}")
-            MESSAGE (STATUS "  library path: ${ENet_LIBRARY}")
-            MESSAGE (STATUS "  libraries:    enet")
-        ENDIF (VERBOSE_FIND)
-    ENDIF (NOT ENet_FIND_QUIETLY)
-ELSE (ENET_FOUND)
-    IF (NOT ENet_INCLUDE_DIR)
-        MESSAGE(SEND_ERROR "ENet include path was not found.")
-    ENDIF (NOT ENet_INCLUDE_DIR)
-    IF (NOT ENet_LIBRARY)
-        MESSAGE(SEND_ERROR "ENet library was not found.")
-    ENDIF (NOT ENet_LIBRARY)
 ENDIF (ENET_FOUND)
 
-MARK_AS_ADVANCED(ENet_INCLUDE_DIR ENet_LIBRARY)
+MARK_AS_ADVANCED(ENet_LIBRARY ENet_INCLUDE_DIR)
@@ -3,7 +3,8 @@
 #
 #  ENET_FOUND - system has enet
-#  ENET_INCLUDE_DIR - the enet include directory
-#  ENET_LIBRARIES - the libraries needed to use enet
-#  ENET_DEFINITIONS - Compiler switches required for using enet
+#  ENet_INCLUDE_DIR - the enet include directory
+#  ENet_LIBRARIES - the libraries needed to use enet
+#
+# $ENETDIR is an environment variable used for finding enet.
 #
 #  Borrowed from The Mana World